API
===

:mod:`discogui.hover`
------------------------

.. automodule:: discogui.hover


:mod:`discogui.taborder`
-------------------------

.. automodule:: discogui.taborder


:mod:`discogui.buttons`
------------------------

.. automodule:: discogui.buttons
